@@ -1,26 +1,36 @@
 def impute_intensities(df, method = "linear"):
     
-    """
-    Fills NaN values contained in a DataFrame consisting of rows of aligned ion intensity.
+    """Fills nan values in data tables.
+    Imputes NaN values contained in a DataFrame consisting of aligned mass spectra.
+    Input DataFrame can be provided by align_spectra().
     
     Extracted Ion Chromatograms often are not of the same length. To generate a set of 
     uniform-length ion intensity series, a multi-step imputation approach is used:
-        I) A baseline is added for all features from the beginning to the end of the experiment.
-        II) Missing values within the detected signal region are interpolated.
+        I)  Missing values within the detected signal region are interpolated.
+        II) A noisy baseline is added for all XIC to be of uniform length which 
+            the length of the longest XIC in the dataset.
     The returned DataFrame is suitable for time series analysis or other multivariate statistics.
     
     Parameters
     ----------    
-    df: A DataFrame containing missing (NaN) values to impute.
+    df : pd.DataFrame 
+         A DataFrame containing missing (NaN) values to be imputed.
+         Input DataFrame can be provided by align_spectra().
     
-    method: Intepolation method to be used; default is "linear". 
-            Supported imputation methods are all methods methods from 
+    method : str
+            Intepolation method to be used; default is "linear". 
+            Supported imputation methods are all  methods from 
             pandas.DataFrame.interpolate() and
             scipy.interpolate.interp1d().
     
     Returns
     -------
-    DataFrame of equal length ion intensity series without NaN.
+    A DataFrame of equal length ion intensity series without NaN.
+    
+    See Also
+    --------
+    align_spectra() : For preparation of the input data.
+    
     
     """
     
